@@ -6,6 +6,7 @@
 #' @param y Unquoted y aesthetic variable.
 #' @param col Unquoted col and fill aesthetic variable.
 #' @param facet Unquoted facet aesthetic variable.
+#' @param facet2 Unquoted second facet variable for a facet grid of facet by facet2 variables.
 #' @param group Unquoted group aesthetic variable.
 #' @param text Unquoted text aesthetic variable, which can be used in combination with plotly::ggplotly(., tooltip = "text").
 #' @param stat Statistical transformation. A character string (e.g. "identity").
@@ -26,6 +27,7 @@
 #' @param x_labels A function that takes the breaks as inputs (e.g. scales::label_comma()), or a vector of labels.
 #' @param x_limits A vector of length 2 to determine the limits of the axis.
 #' @param x_oob A scales::oob_* function for how to deal with out-of-bounds values.
+#' @param x_sec_axis A secondary axis specified by the ggplot2::sec_axis or ggplot2::dup_axis function.
 #' @param x_title Axis title string. Defaults to converting to sentence case with spaces. Use "" for no title.
 #' @param x_trans For a numeric variable, a transformation object (e.g. "log10").
 #' @param y_breaks A function that takes the limits as input (e.g. scales::breaks_pretty()), or a vector of breaks.
@@ -34,8 +36,9 @@
 #' @param y_labels A function that takes the breaks as inputs (e.g. scales::label_comma()), or a vector of labels.
 #' @param y_limits A vector of length 2 to determine the limits of the axis.
 #' @param y_oob A scales::oob_* function for how to deal with out-of-bounds values.
+#' @param y_sec_axis A secondary axis specified by the ggplot2::sec_axis or ggplot2::dup_axis function.
 #' @param y_title Axis title string. Defaults to converting to sentence case with spaces. Use "" for no title.
-#' @param y_trans For a numeric variable, a transformation object (e.g. "log10").#' @param col_breaks A vector of breaks. For a categorical col variable, this links pal values with col variable values dropping those not used. For a numeric variable where col_intervals is NULL, this only affects the labels on the legend.
+#' @param y_trans For a numeric variable, a transformation object (e.g. "log10").
 #' @param col_breaks A function that takes the limits as input (e.g. scales::breaks_pretty()), or a vector of breaks.
 #' @param col_include For a numeric or date variable, any values that the scale should include (e.g. 0).
 #' @param col_intervals A function to cut or chop the numeric variable into intervals (e.g. ~ santoku::chop_mean_sd(.x, drop = FALSE)).
@@ -43,9 +46,8 @@
 #' @param col_limits A vector to determine the limits of the axis.
 #' @param col_legend_ncol The number of columns for the legend elements.
 #' @param col_legend_nrow The number of rows for the legend elements.
-#' @param col_legend_place The place for the legend. "r" for right, "b" for bottom, "t" for top, or "l" for left.
+#' @param col_legend_place The place for the legend. "b" for bottom, "r" for right, "t" for top, or "l" for left.
 #' @param col_title Axis title string. Defaults to converting to sentence case with spaces. Use "" for no title.
-#' @param facet_intervals A function to cut or chop the numeric variable into intervals, including in rlang lambda format (e.g. ~ santoku::chop_mean_sd(.x, drop = FALSE)).
 #' @param facet_labels A function that takes the breaks as inputs (e.g. scales::label_comma()), or a named vector of labels (e.g. c(value = "label", ...)).
 #' @param facet_ncol The number of columns of facetted plots.
 #' @param facet_nrow The number of rows of facetted plots.
@@ -66,64 +68,68 @@
 #'
 #' gg_tile(df, x = x, y = y, col = z)
 #'
-gg_tile <- function(data = NULL,
-                   x = NULL,
-                   y = NULL,
-                   col = NULL,
-                   facet = NULL,
-                   group = NULL,
-                   text = NULL,
-                   stat = "identity",
-                   position = "identity",
-                   pal = NULL,
-                   pal_na = "#7F7F7F",
-                   alpha = 0.9,
-                   #linewidth = 0.5,
-                   height = 1,
-                   width = 1,
-                   ...,
-                   titles = NULL,
-                   title = NULL,
-                   subtitle = NULL,
-                   coord = NULL,
-                   x_breaks = NULL,
-                   x_expand = NULL,
-                   x_include = NULL,
-                   x_labels = NULL,
-                   x_limits = NULL,
-                   x_oob = scales::oob_censor,
-                   x_title = NULL,
-                   x_trans = "identity",
-                   y_breaks = NULL,
-                   y_expand = NULL,
-                   y_include = NULL,
-                   y_labels = NULL,
-                   y_limits = NULL,
-                   y_oob = scales::oob_censor,
-                   y_title = NULL,
-                   y_trans = "identity",
-                   col_breaks = NULL,
-                   col_include = NULL,
-                   col_intervals = NULL,
-                   col_labels = NULL,
-                   col_legend_place = NULL,
-                   col_legend_ncol = NULL,
-                   col_legend_nrow = NULL,
-                   col_limits = NULL,
-                   col_title = NULL,
-                   facet_intervals = NULL,
-                   facet_labels = NULL,
-                   facet_ncol = NULL,
-                   facet_nrow = NULL,
-                   facet_scales = "fixed",
-                   caption = NULL,
-                   theme = NULL) {
+gg_tile <- function(
+    data = NULL,
+    x = NULL,
+    y = NULL,
+    col = NULL,
+    facet = NULL,
+    facet2 = NULL,
+    group = NULL,
+    text = NULL,
+    stat = "identity",
+    position = "identity",
+    pal = NULL,
+    pal_na = "#7F7F7F",
+    alpha = 0.9,
+    #linewidth = 0.5,
+    height = 1,
+    width = 1,
+    ...,
+    titles = NULL,
+    title = NULL,
+    subtitle = NULL,
+    coord = NULL,
+    x_breaks = NULL,
+    x_expand = NULL,
+    x_include = NULL,
+    x_labels = NULL,
+    x_limits = NULL,
+    x_oob = scales::oob_keep,
+    x_sec_axis = ggplot2::waiver(),
+    x_title = NULL,
+    x_trans = "identity",
+    y_breaks = NULL,
+    y_expand = NULL,
+    y_include = NULL,
+    y_labels = NULL,
+    y_limits = NULL,
+    y_oob = scales::oob_keep,
+    y_sec_axis = ggplot2::waiver(),
+    y_title = NULL,
+    y_trans = "identity",
+    col_breaks = NULL,
+    col_include = NULL,
+    col_intervals = NULL,
+    col_labels = NULL,
+    col_legend_place = NULL,
+    col_legend_ncol = NULL,
+    col_legend_nrow = NULL,
+    col_limits = NULL,
+    col_title = NULL,
+    facet_labels = NULL,
+    facet_ncol = NULL,
+    facet_nrow = NULL,
+    facet_scales = "fixed",
+    caption = NULL,
+    theme = NULL) {
 
   #quote
   x <- rlang::enquo(x)
   y <- rlang::enquo(y)
   col <- rlang::enquo(col)
   facet <- rlang::enquo(facet)
+  facet2 <- rlang::enquo(facet2)
   group <- rlang::enquo(group)
   text <- rlang::enquo(text)
 
@@ -203,17 +209,17 @@ gg_tile <- function(data = NULL,
 
   if (rlang::is_null(theme)) {
     if (xy_numeric_date) {
-      x_grid <- FALSE
-      y_grid <- TRUE
+      grid_v <- FALSE
+      grid_h <- TRUE
     }
     else {
-      x_grid <-
+      grid_v <-
         ifelse(is.numeric(rlang::eval_tidy(x, data)) |
                  lubridate::is.Date(rlang::eval_tidy(x, data)) |
                  rlang::quo_is_null(x),
                TRUE,
                FALSE)
-      y_grid <-
+      grid_h <-
         ifelse(is.numeric(rlang::eval_tidy(y, data)) |
                  lubridate::is.Date(rlang::eval_tidy(y, data)) |
                  rlang::quo_is_null(y),
@@ -221,7 +227,7 @@ gg_tile <- function(data = NULL,
                FALSE)
     }
 
-    theme <- gg_theme(x_grid = x_grid, y_grid = y_grid)
+    theme <- gg_theme(grid_v = grid_v, grid_h = grid_h)
   }
 
   # if (rlang::is_null(width)) {
@@ -244,14 +250,14 @@ gg_tile <- function(data = NULL,
   if (!rlang::quo_is_null(x)) {
     if (is.logical(rlang::eval_tidy(x, data))) {
       data <- data %>%
-        dplyr::mutate(dplyr::across(!!x, ~ factor(.x, levels = c("TRUE", "FALSE"))))
+        dplyr::mutate(dplyr::across(!!x, ~ factor(.x, levels = c("FALSE", "TRUE"))))
     }
   }
 
   if (!rlang::quo_is_null(y)) {
     if (is.logical(rlang::eval_tidy(y, data))) {
       data <- data %>%
-        dplyr::mutate(dplyr::across(!!y, ~ factor(.x, levels = c("TRUE", "FALSE"))))
+        dplyr::mutate(dplyr::across(!!y, ~ factor(.x, levels = c("FALSE", "TRUE"))))
     }
 
     if (is.character(rlang::eval_tidy(y, data)) | is.factor(rlang::eval_tidy(y, data))) {
@@ -270,10 +276,10 @@ gg_tile <- function(data = NULL,
 
     if (is.logical(rlang::eval_tidy(col, data))) {
       data <- data %>%
-        dplyr::mutate(dplyr::across(!!col, ~ factor(.x, levels = c("TRUE", "FALSE"))))
+        dplyr::mutate(dplyr::across(!!col, ~ factor(.x, levels = c("FALSE", "TRUE"))))
     }
 
-    if (is.factor(rlang::eval_tidy(col, data)) | is.character(rlang::eval_tidy(col, data))) {
+    if (is.character(rlang::eval_tidy(col, data)) | is.factor(rlang::eval_tidy(col, data))) {
       if (is.factor(rlang::eval_tidy(y, data)) | is.character(rlang::eval_tidy(y, data))) {
         data <- data %>%
           dplyr::mutate(dplyr::across(!!col, ~ forcats::fct_rev(.x)))
@@ -284,12 +290,13 @@ gg_tile <- function(data = NULL,
   if (!rlang::quo_is_null(facet)) {
     if (is.logical(class(rlang::eval_tidy(facet, data)))) {
       data <- data %>%
-        dplyr::mutate(dplyr::across(!!facet, ~ factor(.x, levels = c("TRUE", "FALSE"))))
+        dplyr::mutate(dplyr::across(!!facet, ~ factor(.x, levels = c("FALSE", "TRUE"))))
     }
-
-    if (!rlang::is_null(facet_intervals)) {
+  }
+  if (!rlang::quo_is_null(facet2)) {
+    if (is.logical(class(rlang::eval_tidy(facet2, data)))) {
       data <- data %>%
-        dplyr::mutate(dplyr::across(!!facet, facet_intervals))
+        dplyr::mutate(dplyr::across(!!facet2, ~ factor(.x, levels = c("FALSE", "TRUE"))))
     }
   }
 
@@ -332,8 +339,12 @@ gg_tile <- function(data = NULL,
                (identical(rlang::eval_tidy(col, data), rlang::eval_tidy(facet, data)))) {
         col_legend_place <- "n"
       }
+      else if (!rlang::quo_is_null(facet2) &
+               (identical(rlang::eval_tidy(col, data), rlang::eval_tidy(facet2, data)))) {
+        col_legend_place <- "n"
+      }
       else
-        col_legend_place <- "r"
+        col_legend_place <- "b"
     }
 
     if (is.numeric(rlang::eval_tidy(col, data))) {
@@ -453,14 +464,14 @@ gg_tile <- function(data = NULL,
       if (is.numeric(rlang::eval_tidy(y, data)) |
           lubridate::is.Date(rlang::eval_tidy(y, data))) {
 
-        if (is.factor(rlang::eval_tidy(col, data)) | is.character(rlang::eval_tidy(col, data))) {
+        if (is.character(rlang::eval_tidy(col, data)) | is.factor(rlang::eval_tidy(col, data))) {
           col_legend_rev <- FALSE
         }
         else if (col_legend_place %in% c("b", "t")) col_legend_rev <- FALSE
         else col_legend_rev <- TRUE
       }
       else if (is.factor(rlang::eval_tidy(y, data)) | is.character(rlang::eval_tidy(y, data))) {
-        if (is.factor(rlang::eval_tidy(col, data)) | is.character(rlang::eval_tidy(col, data))) {
+        if (is.character(rlang::eval_tidy(col, data)) | is.factor(rlang::eval_tidy(col, data))) {
           col_legend_rev <- TRUE
         }
         else if (col_legend_place %in% c("b", "t")) col_legend_rev <- TRUE
@@ -598,23 +609,22 @@ gg_tile <- function(data = NULL,
     )
 
   if (!rlang::quo_is_null(facet)) {
-    if (!rlang::is_null(facet_intervals)) {
+    if (rlang::quo_is_null(facet2)) {
       plot <- plot +
         ggplot2::facet_wrap(
           ggplot2::vars(!!facet),
-          scales = facet_scales,
+          scales = facet_scales, labeller = ggplot2::as_labeller(facet_labels),
           ncol = facet_ncol,
           nrow = facet_nrow
         )
     }
     else {
       plot <- plot +
-        ggplot2::facet_wrap(
-          ggplot2::vars(!!facet),
+        ggplot2::facet_grid(
+          rows = ggplot2::vars(!!facet2),
+          cols = ggplot2::vars(!!facet),
           labeller = ggplot2::as_labeller(facet_labels),
-          scales = facet_scales,
-          ncol = facet_ncol,
-          nrow = facet_nrow
+          scales = facet_scales
         )
     }
   }
@@ -654,12 +664,13 @@ gg_tile <- function(data = NULL,
       x_max <- x_vctr %>% max(na.rm = TRUE)
 
       if (rlang::is_null(x_limits)) {
-        x_range <- range(x_min, x_max, x_include)
+        x_limits <- range(c(x_min, x_max))
+        if (!rlang::is_null(x_include)) x_limits <- range(c(x_limits, x_include))
 
         if (rlang::is_null(x_breaks)) {
           x_breaks_n <- ifelse(rlang::quo_is_null(facet), 5, 3)
-          if (x_trans != c("identity")) x_breaks <- scales::breaks_log(n = x_breaks_n, base = 10)(x_range)
-          else x_breaks <- scales::breaks_pretty(n = x_breaks_n)(x_range)
+          if (x_trans != c("identity")) x_breaks <- scales::breaks_log(n = x_breaks_n, base = 10)(x_limits)
+          else x_breaks <- scales::breaks_pretty(n = x_breaks_n)(x_limits)
 
           if (xy_numeric_date) x_limits <- NULL
           else {
@@ -677,7 +688,7 @@ gg_tile <- function(data = NULL,
             else {
               if (x_trans != "identity") x_limits <- NULL
               else {
-                x_limits <- list(x_range) %>%
+                x_limits <- list(x_limits) %>%
                   purrr::map(.f = x_breaks) %>%
                   unlist() %>%
                   range()
@@ -689,7 +700,7 @@ gg_tile <- function(data = NULL,
       else if (!rlang::is_null(x_limits)) {
         if (is.na(x_limits)[1]) x_limits[1] <- x_min
         if (is.na(x_limits)[2]) x_limits[2] <- x_max
-        x_limits <- range(c(x_min, x_max, x_include))
+        if (!rlang::is_null(x_include)) x_limits <- range(c(x_limits, x_include))
 
         if (rlang::is_null(x_breaks)) {
           x_breaks_n <- ifelse(rlang::quo_is_null(facet), 5, 4)
@@ -705,11 +716,11 @@ gg_tile <- function(data = NULL,
     if (rlang::is_null(x_expand)) {
       if (facet_scales %in% c("fixed", "free_y")) {
         if (xy_numeric_date) {
-          x_expand <- c(0.025, 0.025)
+          x_expand <- c(0.05, 0.05)
         }
         else x_expand <- c(0, 0)
       }
-      else x_expand <- c(0.025, 0.025)
+      else x_expand <- c(0.05, 0.05)
     }
 
     if (rlang::is_null(x_labels)) {
@@ -751,7 +762,6 @@ gg_tile <- function(data = NULL,
   }
   else {
     if (facet_scales %in% c("fixed", "free_x")) {
-
       y_vctr <- layer_data %>%
         dplyr::select(tidyselect::matches(stringr::regex("^y$|^ymin$|^ymax$|^yend$|^ymay_final$"))) %>%
         tidyr::pivot_longer(cols = tidyselect::everything()) %>%
@@ -765,12 +775,13 @@ gg_tile <- function(data = NULL,
       y_max <- y_vctr %>% max(na.rm = TRUE)
 
       if (rlang::is_null(y_limits)) {
-        y_range <- range(y_min, y_max, y_include)
+        y_limits <- range(c(y_min, y_max))
+        if (!rlang::is_null(y_include)) y_limits <- range(c(y_limits, y_include))
 
         if (rlang::is_null(y_breaks)) {
-          y_breaks_n <- ifelse(rlang::quo_is_null(facet), 5, 4)
-          if (y_trans != c("identity")) y_breaks <- scales::breaks_log(n = y_breaks_n, base = 10)(y_range)
-          else y_breaks <- scales::breaks_pretty(n = y_breaks_n)(y_range)
+          y_breaks_n <- ifelse(rlang::quo_is_null(facet), 5, 3)
+          if (y_trans != c("identity")) y_breaks <- scales::breaks_log(n = y_breaks_n, base = 10)(y_limits)
+          else y_breaks <- scales::breaks_pretty(n = y_breaks_n)(y_limits)
 
           if (y_trans != "identity") y_limits <- NULL
           else y_limits <- c(min(y_breaks), max(y_breaks))
@@ -783,7 +794,7 @@ gg_tile <- function(data = NULL,
           else {
             if (y_trans != "identity") y_limits <- NULL
             else {
-              y_limits <- list(y_range) %>%
+              y_limits <- list(y_limits) %>%
                 purrr::map(.f = y_breaks) %>%
                 unlist() %>%
                 range()
@@ -794,7 +805,7 @@ gg_tile <- function(data = NULL,
       else if (!rlang::is_null(y_limits)) {
         if (is.na(y_limits)[1]) y_limits[1] <- y_min
         if (is.na(y_limits)[2]) y_limits[2] <- y_max
-        y_limits <- range(c(y_min, y_max, y_include))
+        if (!rlang::is_null(y_include)) y_limits <- range(c(y_limits, y_include))
 
         if (rlang::is_null(y_breaks)) {
           y_breaks_n <- ifelse(rlang::quo_is_null(facet), 5, 4)
@@ -812,9 +823,9 @@ gg_tile <- function(data = NULL,
         y_expand <- c(0, 0)
       }
       else if (!rlang::is_null(y_include)) {
-        if (min(y_include) == 0 | max(y_include) == 0) y_expand <- ggplot2::expansion(mult = c(0, 0.025))
+        if (min(y_include) == 0 | max(y_include) == 0) y_expand <- ggplot2::expansion(mult = c(0, 0.05))
       }
-      else y_expand <- c(0.025, 0.025)
+      else y_expand <- c(0.05, 0.05)
     }
 
     if (rlang::is_null(y_labels)) {
@@ -892,6 +903,11 @@ gg_tile <- function(data = NULL,
       ggplot2::theme(legend.position = "left")
   }
 
+  else if (col_legend_place == "r") {
+    plot <- plot +
+      ggplot2::theme(legend.position = "right")
+  }
+
   #return beautiful plot
   return(plot)
 }
